@@ -2,21 +2,13 @@ use serde::Deserialize;
 use std::iter;
 use swc_common::{Spanned, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::helper;
-use swc_ecma_transforms_base::perf::Check;
+use swc_ecma_transforms_base::{helper, perf::Check};
 use swc_ecma_transforms_macros::fast_path;
-use swc_ecma_utils::alias_ident_for;
-use swc_ecma_utils::alias_if_required;
-use swc_ecma_utils::has_rest_pat;
-use swc_ecma_utils::is_literal;
-use swc_ecma_utils::private_ident;
-use swc_ecma_utils::prop_name_to_expr;
-use swc_ecma_utils::quote_ident;
-use swc_ecma_utils::undefined;
-use swc_ecma_utils::ExprFactory;
-use swc_ecma_utils::StmtLike;
-use swc_ecma_visit::noop_visit_type;
-use swc_ecma_visit::{noop_fold_type, Fold, FoldWith, Node, Visit, VisitWith};
+use swc_ecma_utils::{
+    alias_ident_for, alias_if_required, has_rest_pat, is_literal, private_ident, prop_name_to_expr,
+    quote_ident, undefined, ExprFactory, StmtLike,
+};
+use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit, VisitWith};
 
 /// `@babel/plugin-transform-destructuring`
 ///
